@@ -43,23 +43,11 @@ async def download_worker(session, log_info, work_deque, download_queue):
         for x in range(3):
             try:
                 async with session.get(certlib.DOWNLOAD.format(log_info['url'], start, end)) as response:
-                    if response.status == 429:
-                        logging.info("got http status {}-{}".format(x, response.status))
-                        time.sleep(min(x + 1, 10))
-                        continue
-                    if response.content_type != 'application/json':
-                        text = await response.text()
-                        logging.error("got response {}-{}-{}".format(x, response.content_type, text))
                     entry_list = await response.json()
                     logging.debug("[{}] Retrieved blocks {}-{}...".format(log_info['url'], start, end))
-                    if entry_list.get('error_code', '') == 'rate_limited':
-                        logging.info("{}-{}".format(x, entry_list))
-                        time.sleep(min(x + 1, 10))
-                        continue
                     break
             except Exception as e:
                 logging.error("Exception getting block {}-{}! {}".format(start, end, e))
-                time.sleep(min(x+1, 10))
         else:  # Notorious for else, if we didn't encounter a break our request failed 3 times D:
             with open('/tmp/fails.csv', 'a') as f:
                 f.write(",".join([log_info['url'], str(start), str(end)]))
